#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 executable-path
version:              0.0.3.1
visibility:           public
id:                   executable-path-0.0.3.1-84VowVJXXjdLu8L9GxK1jL
key:                  executable-path-0.0.3.1-84VowVJXXjdLu8L9GxK1jL
license:              LicenseRef-PublicDomain
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".

category:             System
abi:                  2c468fd1d4f0ce32df5ad561eb9fe08e
exposed:              True
exposed-modules:      System.Environment.Executable
hidden-modules:       System.Environment.Executable.Linux
import-dirs:          /usr/lib/ghc-8.10.5/site-local/executable-path-0.0.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/executable-path-0.0.3.1
hs-libraries:         HSexecutable-path-0.0.3.1-84VowVJXXjdLu8L9GxK1jL
depends:
    base-4.14.2.0 directory-1.3.6.0 filepath-1.4.2.1 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-executable-path/html/executable-path.haddock

haddock-html:         /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

